.. cchecksum documentation master file, created by
   sphinx-quickstart on Thu Feb  1 21:29:06 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

cchecksum
=============================================

A ~2x faster drop-in replacement for eth_utils.to_checksum_address. Raises the exact same Exceptions. Implemented in C.

.. automodule:: cchecksum
   :members:
   :undoc-members:
   :show-inheritance:
